record.SaxContentHandler

|  | ## Cheshire3 Object Model: Class SaxContentHandler

Module record :: Class SaxContentHandler

## Class SaxContentHandler
source code

Object Tree:

    xml.sax.handler.ContentHandler --+
                                     |
                                    SaxContentHandler

Instance Methods

__init__(self)
reinit(self)
startPrefixMapping(self, pfx, uri) Begin the scope of a prefix-URI Namespace mapping.
startElement(self, name, attrs) Signals the start of an element in non-namespace mode.
endElement(self, name) Signals the end of an element in non-namespace mode.
startElementNS(self, name, qname, attrs) Signals the start of an element in namespace mode.
endElementNS(self, name, qname) Signals the end of an element in namespace mode.
characters(self, text, start=0, length=-1) Receive notification of character data.
ignorableWhitespace(self, ws) Receive notification of ignorable whitespace in element content.
processingInstruction(self, target, data) Receive notification of a processing instruction.
skippedEntity(self, name) Receive notification of a skipped entity.
Inherited from `xml.sax.handler.ContentHandler`: `endDocument`, `endPrefixMapping`, `setDocumentLocator`, `startDocument`

Class Variables

currentText |
currentPath |
pathLines |
currentLine |
recordSize |
elementHash |
namespaces |
hashAttributesNames |
hashAttributes |
stripWS |
saveElementIndexes |

Method Details

### __init__(self) (Constructor) | source code
Overrides: xml.sax.handler.ContentHandler.__init__

### reinit(self) | source code

### startPrefixMapping(self, pfx, uri) | source code
Begin the scope of a prefix-URI Namespace mapping. The information from this event is not necessary for normal Namespace processing: the SAX XML reader will automatically replace prefixes for element and attribute names when the http://xml.org/sax/features/namespaces feature is true (the default). There are cases, however, when applications need to use prefixes in character data or in attribute values, where they cannot safely be expanded automatically; the start/endPrefixMapping event supplies the information to the application to expand prefixes in those contexts itself, if necessary. Note that start/endPrefixMapping events are not guaranteed to be properly nested relative to each-other: all startPrefixMapping events will occur before the corresponding startElement event, and all endPrefixMapping events will occur after the corresponding endElement event, but their order is not guaranteed. Overrides: xml.sax.handler.ContentHandler.startPrefixMapping (inherited documentation)

### startElement(self, name, attrs) | source code
Signals the start of an element in non-namespace mode. The name parameter contains the raw XML 1.0 name of the element type as a string and the attrs parameter holds an instance of the Attributes class containing the attributes of the element. Overrides: xml.sax.handler.ContentHandler.startElement (inherited documentation)

### endElement(self, name) | source code
Signals the end of an element in non-namespace mode. The name parameter contains the name of the element type, just as with the startElement event. Overrides: xml.sax.handler.ContentHandler.endElement (inherited documentation)

### startElementNS(self, name, qname, attrs) | source code
Signals the start of an element in namespace mode. The name parameter contains the name of the element type as a (uri, localname) tuple, the qname parameter the raw XML 1.0 name used in the source document, and the attrs parameter holds an instance of the Attributes class containing the attributes of the element. The uri part of the name tuple is None for elements which have no namespace. Overrides: xml.sax.handler.ContentHandler.startElementNS (inherited documentation)

### endElementNS(self, name, qname) | source code
Signals the end of an element in namespace mode. The name parameter contains the name of the element type, just as with the startElementNS event. Overrides: xml.sax.handler.ContentHandler.endElementNS (inherited documentation)

### characters(self, text, start=0, length=-1) | source code
Receive notification of character data. The Parser will call this method to report each chunk of character data. SAX parsers may return all contiguous character data in a single chunk, or they may split it into several chunks; however, all of the characters in any single event must come from the same external entity so that the Locator provides useful information. Overrides: xml.sax.handler.ContentHandler.characters (inherited documentation)

### ignorableWhitespace(self, ws) | source code
Receive notification of ignorable whitespace in element content. Validating Parsers must use this method to report each chunk of ignorable whitespace (see the W3C XML 1.0 recommendation, section 2.10): non-validating parsers may also use this method if they are capable of parsing and using content models. SAX parsers may return all contiguous whitespace in a single chunk, or they may split it into several chunks; however, all of the characters in any single event must come from the same external entity, so that the Locator provides useful information. Overrides: xml.sax.handler.ContentHandler.ignorableWhitespace (inherited documentation)

### processingInstruction(self, target, data) | source code
Receive notification of a processing instruction. The Parser will invoke this method once for each processing instruction found: note that processing instructions may occur before or after the main document element. A SAX parser should never report an XML declaration (XML 1.0, section 2.8) or a text declaration (XML 1.0, section 4.3.1) using this method. Overrides: xml.sax.handler.ContentHandler.processingInstruction (inherited documentation)

### skippedEntity(self, name) | source code
Receive notification of a skipped entity. The Parser will invoke this method once for each entity skipped. Non-validating processors may skip entities if they have not seen the declarations (because, for example, the entity was declared in an external DTD subset). All processors may skip external entities, depending on the values of the http://xml.org/sax/features/external-general-entities and the http://xml.org/sax/features/external-parameter-entities properties. Overrides: xml.sax.handler.ContentHandler.skippedEntity (inherited documentation)

Class Variable Details

    ### currentText Value:
        []

    ### currentPath Value:
        []

    ### pathLines Value:
        []

    ### currentLine Value:
        -1

    ### recordSize Value:
        0

    ### elementHash Value:
        {}

    ### namespaces Value:
        []

    ### hashAttributesNames Value:
        {}

    ### hashAttributes Value:
        []

    ### stripWS Value:
        0

    ### saveElementIndexes Value:
        1